# Changelog

All notable changes to **lambic** will be documented in this file.

Format follows [Keep a Changelog](https://keepachangelog.com/).

## [0.5.3] — 2026-04-01

### Changed

- Migrate URI separator `#` → `~` in docstrings, error messages, and tests

## [0.1.0] — 2026-03-11

### Added

- Initial release.
